"""Generic Report operations for metrics reporting"""
from typing import Dict

import arrow

from ws_metrics.enums import ReportEnum
from ws_metrics.schema import AbstractTextFile


class Report:
    """Base class for report generation"""

    def __init__(self, report: ReportEnum, data: Dict):
        self.type = report.title
        self.template = report.template_type
        self.name = self.set_report_title(report)
        self.file = self.render_report_template(data)

    @staticmethod
    def set_report_title(report: ReportEnum) -> str:
        """
        Use the report type to determine the report title

        :param report: The report type to generate
        :return: the title of the report
        """
        timestamp = arrow.now().format("YYYY_MM_DDThh_mm_ss")

        return f"{report.title}_{timestamp}{report.template_type.file_type}"

    def render_report_template(self, data: Dict) -> AbstractTextFile:
        """
        Render template

        :param data: data to use in template
        :return: an AbstractTextFile
        """

        return self.template.render_template(self.name, data)
